StateFlowClient class

Constructors

StateFlowClient({required String baseUrl, Map<String, String> defaultHeaders = const {}, Duration timeout = const Duration(seconds: 30)})

Properties

baseUrl String
final
defaultHeaders Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendRequest(String path, HttpMethod method, {Map<String, String>? headers, dynamic body, List<MultipartFile>? files}) Future<StateFlowResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited