StateFlowResponse class

Constructors

StateFlowResponse(int statusCode, String body, String reasonPhrase)

Properties

body String
final
hashCode int
The hash code for this object.
no setterinherited
reasonPhrase String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited