StateValue<T> class

Constructors

StateValue(String key, T initialValue)
factory

Properties

error Object?
no setter
hashCode int
The hash code for this object.
no setterinherited
isLoading bool
no setter
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setError(Object error) → void
setLoaded(T newValue) → void
setLoading() → void
stopLoading() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited