StateFlow class
Constructors
- StateFlow()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
String key, VoidCallback listener) → void -
dispose(
) → void -
get<
T> (String key) → T? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
String key) → void -
removeListener(
String key, VoidCallback listener) → void -
set<
T> (String key, T value) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
no setter
Static Methods
-
back<
T extends Object?> ([T? result]) → void -
canPop(
) → bool -
currentRoute(
) → String? -
getHistory(
) → List< String> -
maybePop<
T extends Object?> ([T? result]) → Future< bool> -
off<
T extends Object?> (dynamic route, {Object? arguments}) → Future< T?> -
offAll<
T extends Object?> (dynamic route, {Object? arguments}) → Future< T?> -
onGenerateRoute(
RouteSettings settings) → Route -
to<
T extends Object?> (dynamic route, {Object? arguments}) → Future< T?>